#!/bin/bash
#
# pdf2html.sh - script convert a PDF document to editable webpages
# 2015-08 Dany Pinoy <pindanet.be>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# depends on convert, a part of ImageMagick
#
# Gebruik weergeven bij foutief gebruik
#   Er moet een te converteren PDF document meegegeven worden
#   En de afhankelijke onderdelen moeten aanwezig zijn (enkel de aanwezigheid van pdf.js wordt gecontroleerd)
if [ "$#" -ne 1 ] || [ ! -f pdf.js ]; then
    echo "Zorg dat alle afhankelijke bestanden in de doelmap staan."
    echo "Voer het script uit in de doelmap waarin de HTML pagina's terecht moeten komen."
    echo "Gebruik: pdf2html <pdf-file>"
    exit
fi
# Controleer of ImageMagick op de computer geïnstalleerd is
which convert
if [ $? -ne 0 ]; then
  echo "pdf2html gebruikt convert, een onderdeel van ImageMagick."
  echo "pdf2html kan convert niet vinden. Installeer ImageMagick."
  echo "Script afgebroken."
  exit
fi
# Indien nodig worden afhankelijkheden van derden opgehaald
if [ ! -f diff_match_patch.js ]; then
  wget https://google-diff-match-patch.googlecode.com/svn/trunk/javascript/diff_match_patch.js
fi
# Indien nodig worden afhankelijkheden van derden opgehaald en uitgepakt
if [ ! -d tinymce ]; then
  wget https://github.com/tinymce/tinymce-dist/archive/master.zip
  unzip master.zip
  rm master.zip
  mv tinymce-dist-master tinymce
fi
if [ ! -f tinymce/langs/nl.js ]; then
  wget http://www.tinymce.com/i18n/download.php?download=nl
  unzip -d tinymce/ download.php?download=nl
  rm download.php?download=nl
fi
# Indien nodig wordt een map aangemaakt om de naar het PNG formaat omgezette PDF pagina's op te slaan
if [ ! -d png ]; then
  mkdir png
fi
# PDF Document omzetten naar PNG afbeeldingen
#   $1 bevat het opgegeven PDF bestand
#   -density 150 bepaalt de kwaliteit (dpi) van de PNG bestanden
echo "Even geduld, bezig met omzetten van het PDF document, dit kan even duren..."
convert -density 150 "$1" png/page_%04d.png
if [ $? != 0 ]; then
  echo "Fout bij het omzetten van het PDF document naar PNG bestanden."
  echo "Dit script gebruikt ImageMagick, controleer of dit geïnstalleerd is."
  echo "Script afgebroken."
  exit
fi
# Maak een Inhoudsopgave in een HTML-bestand (tekstbestand) aan
  cat <<EOF > content.html
<span onclick="fold(this);" title="Inhoudsopgave">...</span>
EOF
# Maak een HTML pagina per pagina in het PDF document aan
page=0
while [ -f png/page_`printf "%04d" $page`.png ];
do
  # Geef de HTML pagina's een naam page_xxxx.html (xxxx bevat het paginanummer met vier cijfers)
  html=page_`printf "%04d" $page`.html
  # Baseer de HTML pagina op de sjabloonpagina template.html
  cp template.html $html
  # Vervang in de HTML pagina de sjabloon variabelen door hun reële waarden
  img=page_`printf "%04d" $page`.png
  sed -i "s/background.png/$img/g" $html
  # Zorg voor een navigatiesysteem (vorige en volgende pagina)
  prev=page_`printf "%04d" $[page - 1]`.html
  if [ -f $prev ]; then
    sed -i "s/prevpage.html/$prev/g" $html
  else
    sed -i "s/prevpage.html/page_0000.html/g" $html
  fi
  next=page_`printf "%04d" $[page + 1]`.html
  if [ -f png/page_`printf "%04d" $[page + 1]`.png ]; then
    sed -i "s/nextpage.html/$next/g" $html
  else
    sed -i "s/nextpage.html/page_0000.html/g" $html
  fi
  # Voeg de pagina toe aan de Inhoudsopgave
  pagenr=`printf "%04d" $[page]`
  echo "<a href=\"$html\">$pagenr</a>" >> content.html
  # Herhaal de werkwijze voor de volgende pagina
  ((page++))
done